---
id: 401
properties:
- id: author
  name: Author
  type: string
  value: David Thomas, Andrew Hunt
- id: genre
  name: Genre
  type: string
  value: Software Engineering
- id: read
  name: Read
  type: boolean
  value: true
---

# The Pragmatic Programmer

Classic book on software craftsmanship. Good refresher on DRY, orthogonality, and tracer bullets.
